@@ -1,10 +1,6 @@
-use std::io::{self, Cursor};
-
 use crate::bson::oid::ObjectId;
 use crate::bson::DateTime;
 
-use crate::tokio_stream::Stream;
-
 use crate::mime::Mime;
 
 use crate::FileData;
@@ -12,17 +8,17 @@ use crate::FileData;
 /// To represent the file retrieved from MongoDB.
 #[derive(Educe)]
 #[educe(Debug)]
-pub struct FileItem<T: Stream<Item = Result<Cursor<Vec<u8>>, io::Error>> + Unpin> {
+pub struct FileItem {
     pub(crate) file_id: ObjectId,
     pub(crate) create_time: DateTime,
     pub(crate) expire_at: Option<DateTime>,
     pub(crate) mime_type: Mime,
     pub(crate) file_size: u64,
     pub(crate) file_name: String,
-    pub(crate) file_data: FileData<T>,
+    pub(crate) file_data: FileData,
 }
 
-impl<T: Stream<Item = Result<Cursor<Vec<u8>>, io::Error>> + Unpin> FileItem<T> {
+impl FileItem {
     pub fn get_file_id(&self) -> ObjectId {
         self.file_id
     }
@@ -47,7 +43,7 @@ impl<T: Stream<Item = Result<Cursor<Vec<u8>>, io::Error>> + Unpin> FileItem<T> {
         &self.file_name
     }
 
-    pub fn into_file_data(self) -> FileData<T> {
+    pub fn into_file_data(self) -> FileData {
         self.file_data
     }
 }
